function fenner_plot(plotfilename, ns,pip, upper, lower)
% SiO2 TiO2 Al2O3 FeO* MgO MnO CaO K2O Na2O P2O5
%   1   2     3    4    5       6   7   8    9
%
% Plot Fenner diagrams 
fprintf(pip,"set bmargin 0; set tmargin 0; set lmargin 0; set rmargin 0\n");
fprintf(pip,"set multiplot\n");
fprintf(pip,"set size 0.33,0.2\n");
fprintf(pip,"unset key\n");

if ns<10 %mind the C indexing!
    style=50;
else
    style=1;
end

if(length(upper) == 1)
  % If one sample the whole range would be more or less range of volcanics
    upper = [78 4 20 15 10 15 5 10 5];
    lower = [40 0 10 1 0 0 0 0 0];
end


ntic=[3 3 3 3 4 3 3 3 3]; %number of tics in the axis
range=upper - lower;

lenght=range./ntic;

fprintf(pip,"set origin 0.13,0.12\n");
fprintf(pip,"set xlabel 'MgO (wt%%)' \n");
fprintf(pip,"set xrange [] reverse\n");
fprintf(pip,"set format x '%%.0f'\n");
fprintf(pip,"set xtics %1.2f,%1.2f\n",lower(5),lenght(5));
fprintf(pip,"set ylabel 'K_2O (wt%%)' rotate by 90\n");
fprintf(pip,"set format y '%%.1f'\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(8),lenght(8));

xl=lower - (range.*0.1);
for i=1:9
  if(xl(i)<0)
    xl(i)=0;
  end
end

xu=upper + (range.*0.1);

%% Setting up the string
% (gnuplot 4.2)
str=["plot  [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(8)) ":" num2str(xu(8))  "] '" plotfilename "' i 0 u 5:8 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:8 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);

fprintf(pip,"set origin 0.6,0.12\n");
fprintf(pip,"set ylabel 'P_2O_5 (wt%%)' rotate by 90\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(9),lenght(9));
%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(9)) ":" num2str(xu(9))  "] '" plotfilename "' i 0 u 5:9 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:9 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);
         
fprintf(pip,"set xlabel ''\n");
fprintf(pip,"set format x ''\n");


fprintf(pip,"set origin 0.13,0.34\n");
fprintf(pip,"set ylabel 'CaO (wt%%)' rotate by 90\n");
%fprintf(pip, "set format y '%%.0f'\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(6),lenght(6));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(6)) ":" num2str(xu(6))  "]  '" plotfilename "' i 0 u 5:6 t '' w p ls " num2str(style)];

if(ns>1)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:6 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);
 
fprintf(pip,"set origin 0.6,0.34\n");
fprintf(pip,"set ylabel 'Na_2O (wt%%)' rotate by 90\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(7),lenght(7));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(7)) ":" num2str(xu(7))  "]  '" plotfilename "' i 0 u 5:7 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:7 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);

fprintf(pip,"set origin 0.13,0.56\n");
fprintf(pip,"set ylabel 'Al_2O_3 (wt%%)' rotate by 90\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(3),lenght(3));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5)) "][" num2str(xl(3)) ":" num2str(xu(3))  "]  '" plotfilename "' i 0 u 5:3 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:3 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);


fprintf(pip,"set origin 0.6,0.56\n");
fprintf(pip,"set ylabel 'FeO* (wt%%)' rotate by 90\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(4),lenght(4));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(4)) ":" num2str(xu(4))  "]  '" plotfilename "' i 0 u 5:4 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:4 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);

fprintf(pip,"set origin 0.13,0.78\n");
fprintf(pip,"set ylabel 'SiO_2 (wt%%)' rotate by 90\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(1),lenght(1));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(1)) ":" num2str(xu(1))  "]  '" plotfilename "' i 0 u 5:1 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:1 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);
 
fprintf(pip,"set origin 0.6,0.78\n");
fprintf(pip,"set ylabel 'TiO_2 (wt%%)' rotate by 90\n");
%fprintf(pip, "set format y '%%.0f'\n");
fprintf(pip,"set ytics %1.2f,%1.2f\n",lower(2),lenght(2));

%% Setting up the string
% (gnuplot 4.2)
str=["plot [" num2str(xu(5)) ":" num2str(xl(5))  "][" num2str(xl(2)) ":" num2str(xu(2))  "]  '" plotfilename "' i 0 u 5:2 t '' w p ls " num2str(style)];

if(ns>0)
  for k=1:ns
    str=[str ", '' i " num2str(k) " u 5:2 t '' w p ls " num2str(style+k)];
  end
end
  
str=[str "\n"];
fprintf(pip,str);
         
fprintf(pip,"unset multiplot\n");
