function output=norm(data, typeNorm)
% Author Dr. Caco (c) 2012
% (part of this code written together with Jose Palma)
%
% Octave/MatLab implementation of the CIPW calculation code
%
% data comes as
% SiO2,TiO2,Al2O3,Fe2O3,FeO,MnO,MgO,CaO,Na2O,K2O,H20,CO2,P2O5, F,  S
% 
%  1     2    3    4     5   6   7   8   9    10  11  12  13  14  15
%
% output for the CIPW norm should have:
%
% Q C Or Ab An Lc Ne Kp Nc Ac Ns Ks Di MgDi FeDi Wo Hy En Fs
% 1 2 3  4  5  6  7  8  9  10 11 12 13 14   15   16 17 18 19
%
% Ol Fo Fa Cs  Mt Il Hm Tn Pf Ru Ap Fr Py Cc Sp MgSp FeSp Sum
% 20 21 22 23  24 25 26 27 28 29 30 31 32 33 34 35   36   37
%
% The outfile for the Barth-Niggli norm is:
%
% Q C Or Plag Ab An Lc Ne Kp Ac Ns Ks Hy Di Wo En Fs Ol Fo Fa
% 1 2 3  4    5  6  7  8  9  10 11 12 13 14 15 16 17 18 19 20
%
% Cs Mt Hm Il Tn Pf Ru Ap Fr Py Cc Sum
% 21 22 23 24 25 26 27 28 29 30 31  32
%
% Caco (c) 2022 translated from GCDkit into matlab

m=size(data);

Delta=0; % i.e. QFM
 
Delta=10^((Delta-4.74)/4.39);

for i=1:m(1)
	if((data(i,4)==0)&&(data(i,5)~=0))%Iron as FeOt
	   feot=data(i,5);
	   data(i,5)=feot/(1+(Delta*0.8998));
	   data(i,4)=(feot-data(i,5))./0.8998;	   
	elseif((data(i,5)==0)&&(data(i,4)~=0))
	   ferrict=data(i,4);
	   data(i,4)=ferrict./((1.1113/Delta)+1);
           data(i,5)=(ferrict-data(i,4))*0.8998;
	else
           % nothing happens here
        end
end

%normalize to 100 

suma=sum(data,2);
for i=1:m(1)
  data(i,:)=(100*data(i,:))./suma(i);
end

%% Here the code branches into two norms
    
%%%%% CIPW
if (typeNorm >0) % i.e. cipw
    

PM=[60.08 79.9 101.96 159.69 71.85 70.94 40.3 56.08 61.98 94.2 18 44.01 141.94 19 32.06];

%molecular weight of the 36 minerals
MW=[60.08 101.96 556.64 524.42 278.20 436.48 284.10 316.32 105.99 461.99 122.06 154.28 1 216.55 248.09 116.16 1 100.39 131.93 1 140.70 203.78 172.24 231.54 151.75 159.69 196.06 135.98 79.90 336.21 78.08 119.98 100.09 1 142.27 173.81];

output=zeros(m(1),37); %the output matrix; rows results, columns minerals!

for i=1:m(1)
  data(i,:)=data(i,:)./PM;
end

%putting together FeO+MnO
data(:,5)=data(:,5)+data(:,6);

%----------------------------------------

for i=1:m(1)
   [n mgr fer]= cipw(data(i,:));
   n(18)= mgr * n(17);
   n(19) = fer * n(17);
   n(21) = mgr * n(20);
   n(22) = fer * n(20);
   n(14) = mgr * n(13);
   n(15) = fer * n(13);
   n(1:36) = n(1:36) .* MW;
   n(13) = n(14) + n(15);
   n(17) = n(18) + n(19);
   n(20) = n(21) + n(22);
   n(34) = n(35) + n(36);
   n(37) = sum(n(1:13)) + n(16) + n(17) + n(20) + sum(n(23:34)); 
   output(i,:) = n;
end

else % Add the corrected Niggli here
% First, we transform the data to cation %
EW=[60.09 79.9 50.98 79.85 71.85 70.94 40.31 56.08 30.99 47.1 9 44 70.97 27 32.06];

for i=1:m(1)
  data(i,:) = data(i,:)./EW;
end

% We normalize the cations to 100 %
total=100./sum(data,2);

for i=1:m(1)
  data(i,:)=data(i,:).*total(i);
end


% and a matrix in wich we will output normative results
outfile=zeros(m(1),32);

for i=1:m(1)
[n mgr]= niggli(data(i,:));

if(n(14)>0) 
  n(16) = mgr/2;
  n(17) = 50 - n(16);
  n(15) = 50.00;
else
  n(16) = 0;
  n(17) = 0;
  n(15) = 0; 
end

if(n(18)>0)
  n(19) = mgr;
  n(20) = 100 - n(19);
else
  n(19) = 0;
  n(20) = 0;
end

n(4) = n(5)+n(6);
n(32) = sum(n(1:4)) + sum(n(7:14)) + n(18) + sum(n(21:31));

output(i,:) = n;
end


end










