% ---------------------------------------------
% Author: Jose Luis Palma & Joaquin Cortes
% Copyright (c) 2012 University at Buffalo
% Copyright (c) 2013 University of Edinburgh
% Copyright (c) 2018 Edge Hill University 
% See the file "LICENSE.txt" for information on 
% usage and redistribution of this file, and for 
% a DISCLAIMER OF ALL WARRANTIES.
% ---------------------------------------------
%
% This is the Octave implementation of PINGU; this tool produces the
% usual petrological plots and does some compositional processing
% of the data
% _______________________________________


%% read input from rappture fields

% some useful stuff
allokay=1; %flag that needs to be passed in order to continue the algorithm
slash='/'; %forward slash for linux and mac machines
disp(' ');

% open our xml input file.
lib = rpLib(infile);

% retrieve user specified data about the input file 
howinput=rpLibGetString(lib,'input.group(load).choice(howinput).current');
if howinput=='fw'
  filein = rpLibGetString(lib,'input.group(load).string(filein).current');
  filein = strrep(filein,',','.'); %replace comma for dot if the user is latino
elseif howinput=='fl'
  datain = rpLibGetString(lib,'input.group(load).string(fileup).current');
  datain = strrep(datain,',','.'); %replace comma for dot if the user is latino
end

ifheader=rpLibGetString(lib,'input.group(load).boolean(ifheader).current');
if strcmp(ifheader,'yes')
  ifheader=1;
else
  ifheader=0;
end

ifsave=rpLibGetString(lib,'input.group(load).boolean(save).current');
if strcmp(ifsave,'yes')
  pathout= rpLibGetString(lib,'input.group(load).group(save).string(pathout).current');
  fileprefix= rpLibGetString(lib,'input.group(load).group(save).string(fileprefix).current');
  fileprefix= [fileprefix '_'];
else
  pathout='';
  fileprefix='';
end

% check that one of the options to get to the data has been selected
if howinput == 'fn'
  rpLibPutString(lib,'output.string(cmt).current','Please select a method to upload your data',0); 
  allokay=0;
end

% check wether the user wants the data normalized to 100% or use
% raw data
ifnormal=rpLibGetString(lib,'input.group(load).boolean(normal).current');

% if want to plot legend
ifkey=rpLibGetString(lib,'input.group(key).boolean(ifkey).current');

% name of series
series=rpLibGetString(lib,'input.group(key).string(names).current');

%if custom symbols are required
ifsymbols=rpLibGetString(lib,'input.group(symbols).boolean(ifsymbols).current');

% custom symbols
symbols=rpLibGetString(lib,'input.group(symbols).string(symbols).current');

% plotting options
whatplot=rpLibGetString(lib,'input.group(plot).choice(plot).current');

% set output comments
rpLibPutString(lib,'output.string(cmt).about.label','Output summary',0);

% size of the symbol

if(strcmp(ifsymbols,'no'))
  sizes=rpLibGetString(lib,'input.group(plot).choice(sizes).current');%1,2 or 3
else
  sizes=rpLibGetString(lib,'input.group(symbols).number(value14).current');% custom
end
  
%grilla
grilla = rpLibGetString(lib,'input.group(plot).boolean(value9).current');

% get username and path to user's account
%pathR='/home/'; %my debian machine
%pathR='/home/vhub/';   % former vhub's common user's path (Root)
pathR='/home/theghub/'; % the new ghub users path
pathL=length(pathR);
[tmp,pathPWD]=system('pwd');
pathA=pathPWD(pathL+1:length(pathPWD));
pathUser=strtok(pathA,slash);
pathUser=[pathR pathUser slash];

% Check if the user wants stats (classical or Aitchinson versions)
ifClassicStats=rpLibGetString(lib,'input.group(stats).boolean(classicStats).current');
ifAitchStats=rpLibGetString(lib,'input.group(stats).boolean(aitchStats).current');

%% reads the file with input data 

if allokay && strcmp(ifsave,'yes') % make sure that output folder is okay
  
  if strcmp(pathout(1),slash) %if starts with slash, remove it
    pathout=pathout(2:length(pathout));
  end  
  if ~strcmp(pathout(length(pathout)),slash) %if doesn't end with slash, add it
    pathout=[pathout slash];
  end
  
  pathout=[pathUser pathout];
  disp(['Output path: ' pathout])
  
  [status,msg]=mkdir(pathout);
  
  if status==0
    rpLibPutString(lib,'output.string(cmt).current',['Error creating folder in the path specified: ' msg],0);    
    allokay=0;
  end
end

if allokay % creates the string for filein
      
  disp('Reading the input file...');
  
  % save input if data loaded in rappture window
  if howinput == 'fl'
    % save the uploaded data to a file
    filein=[pathout 'data.txt'];
    save("-text",'tmp.txt',"datain");
    system(['grep -v ^# tmp.txt > ' filein]);    %ifheader=ifheader+5; %octave adds 5 header lines when saving the txt file
  else 
    if strcmp(filein(1),slash) %if starts with slash, remove it
      filein=filein(2:length(filein));
    end  
    filein=[pathUser filein];
    disp(['Reading file: ' filein]);    
  end
end


if allokay   % check if the file actually exist if it is being read from the workspace
  
  [w,err,msg]=stat(filein);
  if(err<0)
    allokay=0;
    rpLibPutString(lib,'output.string(cmt).current','File does not exist!',0); 
  end
end

  if allokay %opens the specified file with data in ascii format
 
    [data,fid,msg]=read_txt(filein,ifheader);
   
    if fid<0 %in case there is problem opening that file
      rpLibPutString(lib,'output.string(cmt).current',['Error opening the input file: ' msg],0);    
      allokay=0;
    end
  
  end 

%% normalize the data

if allokay && strcmp(ifnormal,'yes')
  m=size(data);
  % This part of the code recalculates the major elements on a
  % volatile-free basis. However, it keeps the colum with the LOI as
  % it is for legacy purposes. It does not calculates the total iron...yet
  % First it calculates the sum of the considered major elements (no LOI)

  total=100./sum(data(:,2:12),2);
  %... and normalizes!
  for i=1:m(1)
    data(i,2:12)=data(i,2:12).*total(i);
  end
  %put zeros in the LOI column, since the analyses are recalculated volatile-free
  data(:,13)=zeros(m(1),1);
  %------------------------------
end
  
%% save file with key labels

if allokay && strcmp(ifkey,'yes')
  keyfilename=[pathout fileprefix 'key'];
  %   save("-text",[keyfilename '.txt'],"series");
  disp("Saving key file with series' names...");
  fid=fopen([keyfilename '.txt'],'w');
  fprintf(fid,'%s\n',series);
  fclose(fid);
end

%% plots selected diagram 

if allokay
  
  tooldir=getenv('TOOLDIR');
  gpdir=[tooldir '/bin/']; %this one works in vhub's workspace; run the tool with ./middleware/invoke
 %gpdir='/home/jose/Dropbox/code/mytools/pingu/src/';
    
  pip=popen('gnuplot','w'); %open gnuplot pipe
  fprintf(pip,"set datafile missing 'NaN'\n");

 % encoding for accent and umlaut using ISO Latin-1
  fprintf(pip,"set encoding iso_8859_1\n");
  
  % Symbol selection
  
  if(strcmp(ifsymbols,'no'))
    
    switch sizes    
     case '1'
      fprintf(pip,"load '%sstyle1.gp'\n",gpdir); %set terminal and load styles
     case '2'
      fprintf(pip,"load '%sstyle2.gp'\n",gpdir); %set terminal and load styles
     case '3'
      fprintf(pip,"load '%sstyle3.gp'\n",gpdir); %set terminal and load styles
     otherwise
      fprintf(pip,"load '%sstyle1.gp'\n",gpdir); %set terminal and load styles
    endswitch
    
    else
        %sizes 1,2,3
        load_style(pip,symbols,sizes,whatplot,pathout);   
    end    

% This variable here to detect if analyses are out of range
% begins assuming all points are in range with a negative number

    rangeValue = -1;

% This is a variable set to avoid doing twice the svg for harkers and fenners
% I cannot replot because they are multiplots!
     
multiplots = -1;

    switch whatplot
     case 'tas'
      disp('plotting TAS diagram...');
      plotname='TAS plot';
      plotfilename=[pathout fileprefix 'TAS'];

      %Calculate if there are values out of range
      rangeValue = outOfRange(data(:,2),data(:,10)+data(:,11),40,80,0,16);

      fprintf(pip,"load '%stas.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=tas_outfile([plotfilename '.txt'],data); %creates file
                                                     %to use for
                                                     %plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      linea = str2num(rpLibGetString(lib,'input.group(plot).choice(value13).current'));
      tas_plot([plotfilename '.txt'],gpdir,ns-1,pip,linea); %do the plotting with gnuplot
                 
      case 'cox1'
      disp('plotting Cox et al (1979) diagram for volcanic rocks...');
      plotname='COX (volcanic) plot';
      plotfilename=[pathout fileprefix 'COXVOL'];

      %Calculate if there are values out of range
      rangeValue = outOfRange(data(:,2),data(:,10)+data(:,11),35,75,0,16);

      fprintf(pip,"load '%scox1.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=tas_outfile([plotfilename '.txt'],data); %creates file
                                                     %to use for
                                                     %plotting
                                                     %(uses TAS script)
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      linea = str2num(rpLibGetString(lib,'input.group(plot).choice(value13).current'));
      cox_plot([plotfilename '.txt'],gpdir,ns-1,pip,linea); %do the plotting with gnuplot
      
      case 'cox2'
      disp('plotting Cox et al (1979) diagram for igneous rocks...');
      plotname='COX (igneous) plot';
      plotfilename=[pathout fileprefix 'COXGR'];

      %Calculate if there are values out of range
      rangeValue = outOfRange(data(:,2),data(:,10)+data(:,11),35,75,0,16);

      fprintf(pip,"load '%scox2.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=tas_outfile([plotfilename '.txt'],data); %creates file
                                                     %to use for
                                                     %plotting
                                                     %(uses TAS script)
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      linea = str2num(rpLibGetString(lib,'input.group(plot).choice(value13).current'));
      cox_plot([plotfilename '.txt'],gpdir,ns-1,pip,linea); %do the plotting with gnuplot
      
            
     case 'afm'
      disp('plotting AFM diagram...');
      plotname='AFM plot';
      plotfilename=[pathout fileprefix 'AFM'];
      linea = rpLibGetString(lib,'input.group(plot).choice(value13).current');
      fprintf(pip,"load '%safm.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=afm_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%sgrid.gp'\n",gpdir);
      end
      afm_plot([plotfilename '.txt'],ns-1,pip,linea,gpdir); %do the plotting with gnuplot

     case 'jn'
      disp('plotting Jensen (1976) diagram...');
      plotname='Jensen (1976) plot';
      plotfilename=[pathout fileprefix 'JN'];
      fprintf(pip,"load '%sjn.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=jn_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%sgrid.gp'\n",gpdir);
      end
      jn_plot([plotfilename '.txt'],ns-1,pip,gpdir); %do the plotting with gnuplot

     case 'bk'
      disp('plotting Barker (1979) diagram...');
      plotname='Barker (1979) plot';
      plotfilename=[pathout fileprefix 'BK'];
      fprintf(pip,"load '%sbk.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=bk_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%sgrid.gp'\n",gpdir);
      end
      gen3_plot([plotfilename '.txt'],ns-1,pip); %do the plotting with gnuplot
       
     case 'cmas'
      disp('plotting CMAS projection...');
      plotname='CMAS projection';
      plotfilename=[pathout fileprefix 'CMAS'];
      fprintf(pip,"load '%scmas.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=cmas_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%sgrid.gp'\n",gpdir);
      end
      cmas_plot([plotfilename '.txt'],ns-1,pip,gpdir); %do the plotting with gnuplot

     case 'pec' 
      disp('plotting K2O vs SiO2 diagram...');
      plotname='K2O diagram';
      plotfilename=[pathout fileprefix 'PEC'];

      %Calculate if there are values out of range
      rangeValue = outOfRange(data(:,2),data(:,11),40,80,0,5.2);

      fprintf(pip,"load '%spec.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      ns=pec_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      pec_plot([plotfilename '.txt'],ns-1,pip);%do the plot in gnuplot

     case 'adk1' 
      disp('plotting the (La/Yb)N vs YbN diagram...');
      plotname='La/YbN vs YbN diagram';
      plotfilename=[pathout fileprefix 'ADK1'];

      %Calculate if there are values out of range is done in the outfile script

      fprintf(pip,"load '%sadk1.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=adk1_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      adk1_plot([plotfilename '.txt'],ns-1,pip);%do the plot in gnuplot

     case 'adk2' 
      disp('plotting the Sr/Y vs Y  diagram...');
      plotname='Sr/Y vs Y diagram';
      plotfilename=[pathout fileprefix 'ADK2'];

      %Calculate if there are values out of range is done in the outfile script

      fprintf(pip,"load '%sadk2.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=adk2_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      adk2_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

     case 'my74'
      disp('plotting Miyashiro 1974 diagram ...');
      plotname='Miyashiro, 1974 diagram';
      plotfilename=[pathout fileprefix 'MY'];

      %Calculate if there are values out of range
      rangeValue = outOfRange(data(:,2),(data(:,5)*0.8998)+data(:,6),45,80,0,6);

      fprintf(pip,"load '%smiyashiro.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      ns=my74_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      my74_plot([plotfilename '.txt'],ns-1,pip);%do the plot in gnuplot
        
     case 'roche'
      disp('plotting de la Roche et al., 1980 diagram (intrusives)...');
      plotname='de la Roche 1980 diagram (intrusives)';
      plotfilename=[pathout fileprefix 'RCHINT'];

      % Range of values is calculated in the outfile script

      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=roche_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      roche_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

      
     case 'roche_volc'
      disp('plotting de la Roche et al., 1980 diagram (volcanics)...');
      plotname='de la Roche 1980 diagram (volcanics)';
      plotfilename=[pathout fileprefix 'RCHVOL'];
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=roche_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      roche_plot_volc([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

     case 'shand'
      disp('plotting Shand 1927 diagram ...');
      plotname='Shand 1927 diagram';
      plotfilename=[pathout fileprefix 'SH'];
      fprintf(pip,"load '%ssh.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=sh_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      sh_plot([plotfilename '.txt'],ns-1,pip);%do the plot in gnuplot
      
     case 'yoder'
      disp('plotting Yoder and Tilley Fo-Qz-Di-Ne tetrahedron');
      plotname='Yoder and Tilley (1962) projection';
      plotfilename=[pathout fileprefix 'TETRA'];
      fprintf(pip,"load '%stetra.gp'\n",gpdir);
      polar = rpLibGetString(lib,'input.group(plot).integer(value12).current');
      azimut = rpLibGetString(lib,'input.group(plot).integer(value11).current');
      str1=['set view ' polar ',' azimut];
      fprintf(pip,"set title 'Yoder and Tilley (1962) projection'\n");
      fprintf(pip,"%s\n",str1);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=tetra_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      tetra_plot([plotfilename '.txt'],ns-1,pip,gpdir); %do the plotting with gnuplot
      
     case 'harker'
      multiplots = 1;
      disp('plotting Harker variation diagrams ...');
      plotname='Harker';
      plotfilename=[pathout fileprefix 'HKR'];
      fprintf(pip,"set terminal postscript color enhanced font 'Helvetica,10' size 15cm,15cm\n");
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns upper lower]=variation_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      % first pass as eps
      harker_plot([plotfilename '.txt'],ns-1,pip,upper,lower);
      % second pass as svg
      fprintf(pip,"set terminal svg enhanced font 'Helvetica,10'\n");
      fprintf(pip,"set output '%s.svg'\n",plotfilename);
      harker_plot([plotfilename '.txt'],ns-1,pip,upper,lower);

      case 'fenner'
       multiplots = 1;
       disp('plotting Fenner variation diagrams ...');
       plotname='Fenner';
       plotfilename=[pathout fileprefix 'FNR'];
       fprintf(pip,"set terminal postscript color enhanced font 'Helvetica,10' size 15cm,15cm\n");
       fprintf(pip,"set output '%s.eps'\n",plotfilename);
       [ns upper lower]=variation_outfile([plotfilename '.txt'],data); %creates file to use for plotting
       if  strcmp(grilla,'yes')
         fprintf(pip,"set grid\n");
       end
       % First pass as eps
       fenner_plot([plotfilename '.txt'],ns-1,pip,upper,lower);
       % second pass as svg
       fprintf(pip,"set terminal svg enhanced font 'Helvetica,10'\n");
       fprintf(pip,"set output '%s.svg'\n",plotfilename);
       fenner_plot([plotfilename '.txt'],ns-1,pip,upper,lower);
                  
     case 'ree'
      disp('plotting REE element diagram ...');
      plotname='REE';
      plotfilename=[pathout fileprefix 'REE'];
      fprintf(pip,"load '%sree.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=ree_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      ree_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];
         
     case 'sm'
      disp('plotting Spider element diagram normalized vs N-MORB...');
      plotname='SM_LILE/HFS';
      plotfilename=[pathout fileprefix 'SMLILEHF'];
      fprintf(pip,"load '%ssm.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=sm_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      sm_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];
         
     case 'sm1'
      disp('plotting Spider element diagram normalized vs N-MORB...');
      plotname='SM/N_MORB';
      plotfilename=[pathout fileprefix 'SMMORB'];
      fprintf(pip,"load '%ssm1.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=sm1_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      sm1_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];
         
     case 'sm2'
      disp('plotting Spider element diagram normalized vs chondrite...');
      plotname='SM/CHR';
      plotfilename=[pathout fileprefix 'SMCHR'];
      fprintf(pip,"load '%ssm2.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=sm2_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      sm2_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];
         
     case 'sm3'
      disp('plotting Spider element diagram normalized vs OIB...');
      plotname='SM/OIB';
      plotfilename=[pathout fileprefix 'SMOIB'];
      fprintf(pip,"load '%ssm3.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=sm3_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      sm3_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];

      case 'sm4'
      disp('plotting Spider element diagram normalized vs Primitive Mantle...');
      plotname='SM/PM';
      plotfilename=[pathout fileprefix 'SMPM'];
      fprintf(pip,"load '%ssm4.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);
      [ns1,range]=sm4_outfile([plotfilename '.txt'],data);
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid ytics noxtics\n");
      end
      % sm3_plot.m works also for this plot!
      sm3_plot([plotfilename '.txt'],ns1,range,pip);
      ns=size(ns1);
      ns(:,2)=[];
      
     case 'pc1'
      disp('plotting Ti-Zr-Y discrimination diagram');
      plotname='Ti-Zr-Y';
      plotfilename=[pathout fileprefix 'TIZRY'];
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%spc1a.gp'\n",gpdir);
      else 
        fprintf(pip,"load '%spc1.gp'\n",gpdir);
      end
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=pc1_outfile([plotfilename '.txt'],data); %creates file to use for plotting  
      pc1_plot([plotfilename '.txt'],ns-1,pip,gpdir); %do the plotting with gnuplot         
         
     case 'pc2'
      disp('plotting Ti-Zr-Sr discrimination diagram');
      plotname='Ti-Zr-Sr';
      plotfilename=[pathout fileprefix 'TIZRSR'];
      if  strcmp(grilla,'yes')
        fprintf(pip,"load '%spc2a.gp'\n",gpdir);
      else 
        fprintf(pip,"load '%spc2.gp'\n",gpdir);
      end
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      ns=pc2_outfile([plotfilename '.txt'],data); %creates file to use for plotting  
      pc2_plot([plotfilename '.txt'],ns-1,pip,gpdir); %do the plotting with gnuplot       
      
     case 'pc3'
      disp('plotting Ti vs Zr discrimination diagram');
      plotname='Ti-Zr';
      plotfilename=[pathout fileprefix 'TIZR'];
      
      % Range done in the outfile script
      
      fprintf(pip,"load '%spc3.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      [ns rangeValue]=pc3_outfile([plotfilename '.txt'],data); %creates file to use for plotting        
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid\n");
      end
      pc3_plot([plotfilename '.txt'],ns-1,pip); %do the plotting with gnuplot   

     case 'nby'
      disp('plotting Nb vs Y diagram...');
      plotname='Nb vs Y diagram';
      plotfilename=[pathout fileprefix 'NBY'];
      fprintf(pip,"load '%snby.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=nby_outfile([plotfilename '.txt'],data); %creates file to use for plotting         
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      nby_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

     case 'tayb'
      disp('plotting Ta vs Yb diagram...');
      plotname='Ta vs Yb diagram';
      plotfilename=[pathout fileprefix 'TAYB'];
      fprintf(pip,"load '%stayb.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=tayb_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      tayb_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

     case 'rbynb'
      disp('plotting Rb vs Y+Nb diagram...');
      plotname='Rb vs Y+Nb diagram';
      plotfilename=[pathout fileprefix 'RBYNB'];
      fprintf(pip,"load '%srbynb.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=rbynb_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      rbynb_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot

     case 'rbybta'
      disp('plotting Rb vs Yb+Ta diagram...');
      plotname='Rb vs Yb+Ta diagram';
      plotfilename=[pathout fileprefix 'RBYBTA'];
      fprintf(pip,"load '%srbybta.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=rbybta_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      rbybta_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot 
      
     case 'w1'
      disp('plotting Nb/Y vs Zr/TiO2 diagram...');
      plotname='Nb/Y vs Zr/TiO2 diagram';
      plotfilename=[pathout fileprefix 'NbYZrTi'];
      fprintf(pip,"load '%sw1.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=w1_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      w1_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot 
          
     case 'w3'
      disp('plotting Nb/Y vs SiO2 diagram...');
      plotname='Nb/Y vs SiO2 diagram';
      plotfilename=[pathout fileprefix 'NbYSi'];
      fprintf(pip,"load '%sw2.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue] =w2_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      w2_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot 
      
          
     case 'w2'
      disp('plotting Zr/TiO2 vs SiO2 diagram...');
      plotname='Zr/TiO2 vs SiO2 diagram';
      plotfilename=[pathout fileprefix 'ZrTiSi'];
      fprintf(pip,"load '%sw3.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename);%set the name (and creates) output file
      [ns rangeValue]=w3_outfile([plotfilename '.txt'],data); %creates file to use for plotting
      if  strcmp(grilla,'yes')
        fprintf(pip,"set grid xtics mxtics\n");
        fprintf(pip,"set grid ytics mytics\n");
      end
      w3_plot([plotfilename '.txt'],ns-1,pip,gpdir);%do the plot in gnuplot 
      
     
     case 'gen2'
      disp('plotting binary (X-Y) diagram...');
      % is the plot square?
      cuadro=rpLibGetString(lib,'input.group(plot).boolean(square).current');
      % do we want a reverse X axis?
      reverseX=rpLibGetString(lib,'input.group(plot).boolean(reverse).current');
      % range X and range Y strings
      rangeX=rpLibGetString(lib,'input.group(plot).string(rangeX).current');
      rangeY=rpLibGetString(lib,'input.group(plot).string(rangeY).current');
      % Logarithm scale bussiness         
      LogScaleX = rpLibGetString(lib,'input.group(plot).boolean(value2).current');
      LogScaleY = rpLibGetString(lib,'input.group(plot).boolean(value5).current');
      %get the elements selected         
      axisX = rpLibGetString(lib,'input.group(plot).choice(axisX).current');
      axisY = rpLibGetString(lib,'input.group(plot).choice(axisY).current');
      axisX=str2num(axisX)+1;
      axisY=str2num(axisY)+1;         
      element={'serie','SiO_2','TiO_2','Al_2O_3','Fe_2O_3','FeO','MnO','MgO','CaO','Na_2O','K_2O','P_2O_5','LOI','Cs','Rb','Ba','Th','U','Pb','Ta','Nb','Sr','Hf','Zr','Y','La','Ce','Pr','Nd','Pm','Sm','Eu','Gd','Tb','Dy','Ho','Er','Tm','Yb','Lu'};
         
      if(axisX==41)
        ejeX = rpLibGetString(lib,'input.group(plot).string(value6).current'); 
        unitsX='';
      else
        if(axisX<=12)
          unitsX='(wt%)';
        else
          unitsX='(ppm)';
        end
        ejeX=element{axisX};
      end
         
      if(axisY==42)
        ejeY = rpLibGetString(lib,'input.group(plot).string(value7).current');
        unitsY='';
      else
        if(axisY<=12)
          unitsY='(wt%)';
        else
          unitsY='(ppm)';
        end
        ejeY=element{axisY};
      end  
      %set things up
      if((axisX==41)||axisY==42)
        dupla='customXY';
      else
        dupla=[ejeX '-' ejeY];
      end

      plotname=[dupla ' plot'];
      plotfilename=[pathout fileprefix dupla];
      fprintf(pip,"load '%sgen2.gp'\n",gpdir);
      fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
      %and creates de diagram
      [ns maxim minim]=gen2_outfile([plotfilename '.txt'],data,axisX,axisY,ejeX,ejeY,cuadro,LogScaleX,LogScaleY); %creates the file to use for plotting
      %but first add labels
   
      if (strcmp(LogScaleX,'yes') && strcmp(cuadro,'no'))
        fprintf(pip,"set logscale x\n");
        fprintf(pip,"set xlabel '%s %s'\n",ejeX,unitsX);
      else
        fprintf(pip,"set xlabel '%s %s'\n",ejeX,unitsX);            
      end
         
      if (strcmp(LogScaleY,'yes') && strcmp(cuadro,'no'))
        fprintf(pip,"set logscale y\n");
        fprintf(pip,"set ylabel '%s %s'\n",ejeY,unitsY);           
      else
        fprintf(pip,"set ylabel '%s %s'\n",ejeY,unitsY);
      end
         
         %reversing the axis, log scale and square plot shouldn't
         %work together!
         
         if (strcmp(LogScaleY,'yes') && strcmp(cuadro,'yes')) 
           reverseX='no';
         end
         if (strcmp(LogScaleX,'yes') && strcmp(cuadro,'yes'))
           reverseX='no';
         end
         
         if(strcmp(reverseX,'yes') && strcmp(cuadro,'no'))
           maxim(1,1)=max(data(:,axisX));
           minim(1,1)=min(data(:,axisX));
         end
         
         if (strcmp(LogScaleX,'yes') && strcmp(reverseX,'yes'))
         % a crappy solution for a twisted plot
           maxim(1,1)=100;
           minim(1,1)=0.1;
         end
         
         % ... and don't forget the grid options
         if  (strcmp(LogScaleY,'no') && strcmp(LogScaleX,'no') && strcmp(grilla,'yes'))
           fprintf(pip,"set grid\n");
         end
         
         if  (strcmp(LogScaleY,'yes') && strcmp(LogScaleX,'no') && strcmp(grilla,'yes'))
           fprintf(pip,"set grid xtics ytics mytics\n");
         end
         
         if  (strcmp(LogScaleY,'no') && strcmp(LogScaleX,'yes') && strcmp(grilla,'yes'))
           fprintf(pip,"set grid xtics mxtics ytics\n");
         end
                  
         if  (strcmp(LogScaleY,'yes') && strcmp(LogScaleX,'yes') && strcmp(grilla,'yes'))
           fprintf(pip,"set grid xtics mxtics ytics mytics\n");
         end
         
         gen2_plot([plotfilename '.txt'],ns-1,pip,cuadro,reverseX,rangeX,rangeY,LogScaleX,LogScaleY,maxim,minim); %do the plotting with gnuplot

         % The part of the script that deals with the range ... messy solution as there are too many options

           if (strcmp(rangeX,'default')==false) % user input of X axis values
              rangeX = strsplit(rangeX,':');
              xMax = str2num(rangeX{2});
              xMin = str2num(rangeX{1});
              if((maxim(1,1)>xMax) || (minim(1,1) < xMin))
                 rangeValue = 1;
              end
           end

           if (strcmp(rangeY,'default')==false) % user input of X axis values
              rangeY = strsplit(rangeY,':');
              yMax = str2num(rangeY{2});
              yMin = str2num(rangeY{1});
              if((maxim(1,2)>yMax) || (minim(1,2) < yMin))
                 rangeValue = 1;
              end
           end
                 
         
         
     case 'gen3'
      disp('plotting ternary diagram...');
      %get the elements selected
      axisX = rpLibGetString(lib,'input.group(plot).choice(axisX).current');
      axisY = rpLibGetString(lib,'input.group(plot).choice(axisY).current');
      axisZ = rpLibGetString(lib,'input.group(plot).choice(axisZ).current');          
      axisX=str2num(axisX)+1;
      axisY=str2num(axisY)+1;        
      axisZ=str2num(axisZ)+1;
       
      element={'serie','SiO_2','TiO_2','Al_2O_3','Fe_2_O3','FeO','MnO','MgO','CaO','Na_2O','K_2O','P_2O_5','LOI','Cs','Rb','Ba','Th','U','Pb','Ta','Nb','Sr','Hf','Zr','Y','La','Ce','Pr','Nd','Pm','Sm','Eu','Gd','Tb','Dy','Ho','Er','Tm','Yb','Lu'};
      if(axisX==41)
        ejeX = rpLibGetString(lib,'input.group(plot).string(value6).current');           
        unitsX='';
      else
        if(axisX<=12)
          unitsX='(wt%)';
        else
          unitsX='(ppm)';
        end
        ejeX=element{axisX};
      end
           
         
      if(axisY==42)
        ejeY = rpLibGetString(lib,'input.group(plot).string(value7).current');
           unitsY='';
      else
        if(axisY<=12)
          unitsY='(wt%)';
        else
          unitsY='(ppm)';
        end
        ejeY=element{axisY};
      end 
           
      if(axisZ==43)
        ejeZ = rpLibGetString(lib,'input.group(plot).string(value8).current');
        unitsZ='';           
      else
        if(axisZ<=12)
          unitsZ='(wt%)';
        else
          unitsZ='(ppm)';
        end
        ejeZ=element{axisZ};
      end       
         
       %set things up
       if((axisX==41)||(axisY==42)||(axisZ==43))
         trio='customXYZ'
       else
         trio=[ejeX '-' ejeY '-' ejeZ];
       end
       plotname=[trio ' plot'];
       plotfilename=[pathout fileprefix trio];
       fprintf(pip,"load '%sgen3.gp'\n",gpdir);
       if  strcmp(grilla,'yes')
         fprintf(pip,"load '%sgrid.gp'\n",gpdir);
       end
       fprintf(pip,"set output '%s.eps'\n",plotfilename); %set name of output file
                                                          %and creates de diagram
       ns=gen3_outfile([plotfilename '.txt'],data,axisX,axisY,axisZ,ejeX,ejeY,ejeZ); %creates the file to use for plotting
         %but first add labels
       fprintf(pip,"set label '%s %s' at 0,-0.03 center\n",ejeX,unitsX);
       fprintf(pip,"set label '%s %s' at 1,-0.03 center\n",ejeY,unitsY);
       fprintf(pip,"set label '%s %s' at 0.5, 0.886 center\n",ejeZ,unitsZ);
       
       gen3_plot([plotfilename '.txt'],ns-1,pip); %do the plotting with gnuplot

       otherwise
        rpLibPutString(lib,'output.string(cmt).current',"Sorry, this plot is not yet implemented\n",0);
         
       endswitch

   % These are the lines to make the svg 
if(multiplots < 0)
       fprintf(pip, "set terminal svg\n");
       fprintf(pip,"set output '%s.svg'\n",plotfilename);
       fprintf(pip, "replot\n");
end

   % makes the key (eps & svg)
   if strcmp(ifkey,'yes')
     fprintf(pip,"set terminal postscript color enhanced\n");
     fprintf(pip,"unset grid\n"); % the key shouldn't have a grid!
     key_plot(pip,keyfilename,ns,ifsymbols,gpdir,pathout);
   end 

   pclose(pip);
  
   
   %convert eps to hig-res jpg
   disp('converting eps file to jpg format for display...');
   str=['convert -density 300 -rotate 90 ' plotfilename '.eps ' plotfilename '.jpg'];
   system(str);
   if strcmp(ifkey,'yes')
     str_key=['convert -density 300 -rotate 90 ' keyfilename '.eps ' keyfilename '.jpg'];   
     system(str_key);
   end
end

    % Doing the stats here...
    % 
    
    if allokay
      
    Elements={"SiO2","TiO2","Al2O3","FeO*","MnO","MgO","CaO","Na2O","K2O","P2O5"};
    if (strcmp(ifClassicStats,'yes'))
      [classic classicCov] = cstats(data);
      rpLibPutString(lib,'output.string(summary).current',"Clasical statistic summary\n",1);
      rpLibPutString(lib,'output.string(summary).current',"Element\tMax\tMin\tMean\tMedian\tMode\tRange\tiqr\tMean Square\tstd\tskewness\tkurtosis\tq 0.0\tq 0.25\tq 0.50\tq 0.75\tq1.00\n",1);
      for i=1:10
        stringy=sprintf(['\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n'],classic(i,:));
        stringy=[Elements{1,i} stringy];
        rpLibPutString(lib,'output.string(summary).current',stringy,1);
      end
    
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"Covariance Matrix\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\tSiO2\tTiO2\tAl2O3\tFeO*\tMnO\tMgO\tCaO\tNa2O\tK2O\tP2O5\n",1);
      for i=1:10
        stringy=sprintf(['\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\' ...
                         't%2.4f\t%2.4f\t%2.4f\t%2.4f\n'],classicCov(i,:));
        stringy=[Elements{1,i} stringy];
        rpLibPutString(lib,'output.string(summary).current',stringy,1);
      end
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
    end
    
    if (strcmp(ifAitchStats,'yes'))
      [simplex simplexVar totVar]=astats(data);
      rpLibPutString(lib,'output.string(summary).current',"Simplicial (Aitchison's) statistic summary\n",1);
      rpLibPutString(lib,'output.string(summary).current',"Element\tMean\tq 0.0\tq 0.25\tq 0.50\tq 0.75\tq1.00\n",1);
      for i=1:10
        stringy=sprintf(['\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n'],simplex(i,:));
        stringy=[Elements{1,i} stringy];
        rpLibPutString(lib,'output.string(summary).current',stringy,1);
      end
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\t\t\t\t\tAitchison's Variance Matrix (top corner)\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\tSiO2\tTiO2\tAl2O3\tFeO*\tMnO\tMgO\tCaO\tNa2O\tK2O\tP2O5\tclr variances\n",1);
      for i=1:10
        rpLibPutString(lib,'output.string(summary).current', Elements{1,i},1); % label first
        for j=1:10
          if(i==j)
            rpLibPutString(lib,'output.string(summary).current',"\t",1);
          else
            stringy=sprintf('\t%2.4f',simplexVar(i,j));
            rpLibPutString(lib,'output.string(summary).current',stringy,1);
          end
        end
        stringy=sprintf('\t%2.4f\n',simplexVar(i,11)); % clr variance
        rpLibPutString(lib,'output.string(summary).current',stringy,1);
      end
      rpLibPutString(lib,'output.string(summary).current', "\tAitchison's Expected Values Matrix (lower corner)\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      rpLibPutString(lib,'output.string(summary).current',"\n",1);
      stringy=sprintf('Simplicial total variance:  %2.4f\n',totVar);
      rpLibPutString(lib,'output.string(summary).current',stringy,1);     
    end
    
    if(strcmp(ifAitchStats,'no') && strcmp(ifClassicStats,'no'))
      rpLibPutString(lib,'output.string(summary).current',"No data stats were calculated",0);
    end
%      [aitch aitchCov] = astats(data);
%            rpLibPutString(lib,'output.string(summary).current',"Aitchison statistic summary\n",1);
%      rpLibPutString(lib,'output.string(summary).current',"Element\ ...
%                     tMax\tMin\tMean\tMedian\tMode\tRange\tiqr\tMean Square\tstd\tskewness\tkurtosis\tq 0.0\tq 0.25\tq 0.50\tq 0.75\tq1.00\n",1);
%      for i=1:10
%        stringy=sprintf(['\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\' ...
%                         't%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f'],aitch(i,:));
%        stringy=[Elements{1,i} stringy];
%        rpLibPutString(lib,'output.string(summary).current',stringy,1);
%      end
%    end

%% creates the rest of rappture output

    
   %Output summary
   rpLibPutString(lib,'output.string(cmt).current',"Files created:\n",0);
   if strcmp(howinput,'fl')
     rpLibPutString(lib,'output.string(cmt).current',[filein " Uploaded data file\n"],1);
   end
   rpLibPutString(lib,'output.string(cmt).current',[plotfilename ".eps Figure in postscript format\n"],1);
   rpLibPutString(lib,'output.string(cmt).current',[plotfilename ".svg Figure in svg format\n"],1);
   rpLibPutString(lib,'output.string(cmt).current',[plotfilename ".jpg Figure in jpeg format\n"],1);
   rpLibPutString(lib,'output.string(cmt).current',[plotfilename ".txt Text file with values plotted\n"],1);      

   % Checking if points are off range
   if(rangeValue > 0)
     rpLibPutString(lib,'output.string(cmt).current','WARNING, some datapoints are outside the range of the plot!',1);
   end

   if strcmp(ifkey,'yes')
     rpLibPutString(lib,'output.strint(cmt).current','',1);
     rpLibPutString(lib,'output.string(cmt).current',[keyfilename ".eps Figure with the key in postcript format\n"],1);
     rpLibPutString(lib,'output.string(cmt).current',[keyfilename ".svg Figure with the key in svg format\n"],1);
     rpLibPutString(lib,'output.string(cmt).current',[keyfilename ".jpg Figure with the key in jpeg format\n"],1);
     rpLibPutString(lib,'output.string(cmt).current',[keyfilename ".txt Text file with the names of the series\n"],1);
   end
      
   %figure
   rpLibPutString(lib,'output.image(outvar).about.label',plotname,0);
   rpLibPutString(lib,'output.image(outvar).current','',0);
   rpLibPutFile(lib,'output.image(outvar).current',[plotfilename '.jpg'],1,0);
   if strcmp(ifkey,'yes')
     rpLibPutString(lib,'output.image(key).about.label','Key',0);
     rpLibPutFile(lib,'output.image(key).current',[keyfilename '.jpg'],1,0);
   end
end 

% signal the end of processing
rpLibResult(lib);

quit; %instead of return, 'quit' exits the octave session
