function [data,varargout]=read_txt(filename,varargin)
%function data=read_txt(filename,ifheader)
%
%Reads compositions from a file in which components are separated by tabs.
%If a second input argument is added and it is 1 (one) it means that the file
%has a header, which will be skipped. 
%
%Order of components (in columns):
%serie SiO2 TiO2 Al2O3 Fe2O3 FeO MnO MgO CaO Na2O K2O P2O5 LOI Cs
%Rb Ba Th U Pb Ta Nb Sr Hf Zr Y La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb Lu X Y Z
%(43 columns in total)
%
%The data is ordered as the input file, with samples in rows

[fid,msg]=fopen(filename,'r');

if nargout>1
   varargout{1}=fid;
end

if nargout>2
   varargout{2}=msg;
end

%if specified by adding input argument to the function, read header line first
if nargin>1 && (varargin{1}==1 || varargin{1}=='yes') && fid>0
   tmp=fgets(fid);
elseif nargin>1 && varargin{1}>1 && fid>0
   for i=1:varargin{1}
      tmp=fgets(fid);
   end
end
   
%now reads the formatted data (samples made up of 42 components in each row)
if fid>0
   data=fscanf(fid,'%f',[43 Inf]);
   data=data';
end

% The size of the matrix
m=size(data);

% We replace the NaN in the major element data by zeros
% we leave the NaN in the trace element data untouched
for i=1:m(1)
    for j=2:13
        if(isnan(data(i,j))==1)
            data(i,j)=0;
        end
    end
end

% We check for zeros in the trace element data
% and we replace for NaN to avoid problem with plots with log axis
for i=1:m(1)
  for j=14:40
    if(data(i,j)<=0) % to avoid problems with 0.0
      data(i,j)=NaN;
    end
  end
end

%------------------------------
% We delete the unwanted rows
% (those rows with a negative serie value)
for i=m(1):-1:1
  if(data(i,1)<0)
    data(i,:)=[];
  end
end
%finally we close the file
if fid>0
   fclose(fid);
end

end
