function [ns1, range]=sm3_outfile(filename,D)
%ree_outfile(filename,D)
%
%This function creates an ASCII file with the name filename that contains
%the data to be plotted in a Spider diagram; Sun & McDonough
%style. Normalized vs OIB full set.
%D is the matrix with the whole database:
% D(:,1) serie D(:,2:13) major elements D(:,14:29) REE elements
% ns differs here from other plots and it is like the original
% series count vector
% Elements needed:
%        Cs Rb Ba Th U  Nb K  La Ce Pb Pr Sr P  Nd Zr Sm Eu Ti Dy Y  Yb Lu
%        14 15 16 17 18 21 11 26 27 19 28 22 12 29 24 31 32 3  35 25 39 40

% First we sort the data in case it comes scrambled
    D=sortrows(D);
    
    m=size(D);

% We will change any possible zero for a NaN
% For perverse data as Holly's 
for i=1:m(1)
    for j=1:m(2)
        if(D(i,j)<=0)
            D(i,j)=NaN;
        end
    end
end

    
    str=['CsRbBaThU NbK LaCePbPrSrP NdZrSmEuTiDyY YbLu'];%44 characters
sm=[0.387 31 350 4 1.02 48 12000 37 80 3.2 9.7 660 2700 38.5 280 10 ...
   3 17200 5.6 29 2.16 0.3];
        fid=fopen(filename,'w');
        fprintf(fid,'#elements\tsamples 1:%d in each column\n',m(1));
        [a,ind]=sort(D(:,1));
%------------------------------
%The old series count script now used in this context    
dummy=D(ind(1),1);
ns(1,1)=1;

n=1; %number of series
for i=2:m(1)
    if (D(ind(i),1)~=dummy)
        ns(n,2)=ind(i-1)+1;
        n=n+1;
        ns(n,1)=ind(i);
        dummy=D(ind(i),1);
    end
end
ns(n,2)=m(1)+1;
ns1=ns(:,2)-ns(:,1);
%------------------------------
% now preparing the data
D=[D(:,14) D(:,15) D(:,16) D(:,17) D(:,18) D(:,21) D(:,11) D(:,26) D(:,27) D(:,19) D(:,28) D(:,22) D(:,12) D(:,29) D(:,24) D(:,31) D(:,32) D(:,3) D(:,35) D(:,25) D(:,39) D(:,40)];
%Dealing with oxides (K2O, TiO2 P2O5)
Kfactor=7096;
Tifactor=5993;
Pfactor=2182;
D(:,7)=D(:,7).*Kfactor;
D(:,13)=D(:,13).*Pfactor;
D(:,18)=D(:,18).*Tifactor;
% normalizing
for i=1:m(1)
    D(i,:)=D(i,:)./sm;
end
%finding the maximum and minimum value of the normalized data
range=[max(max(D)) min(min(D))];

% generating the rest of the output
     j=1;
for i=1:2:43 %labels
    fprintf(fid,'%s',str(i:i+1));
    for k=1:m(1)
        fprintf(fid,'\t%f',D(k,j));
    end
    fprintf(fid,'\n');
    j=j+1;
end
fclose(fid);
end
