function ns=tetra_outfile(filename,D)
%ns=tetra_outfile(filename,D)
%
%This function creates an ASCII file with the name filename that contains
%the data to be plotted in the Yoder tetrahedron.
%D is the matrix with the whole database (13 columns and samples in rows)
%ns is the number of series in the data

%series, SiO2, TiO2, Al2O3, Fe2O3, FeO, MnO, MgO, CaO, Na2O, K2O,
%P2O5, LOI, Cs, Rb, Ba, Th, U, Pb, Ta, Nb, Sr, Hf, Zr, Y, La, Ce,
%Pr, Nd, Sm, Eu, Gd, Tb, Dy, Ho, Er, Tm, Yb, Lu, X, Y, Z

N=size(D,1);

fid=fopen(filename,'w');
fprintf(fid,'# x y z\n'); %coordinate system for splot

%Preparing the data in order to use norm.m

D2a=[D(:,2:11) zeros(N(1),2) D(:,12) zeros(N(1),2)];

D2a=norm(D2a,1); % one for cipw and -1 for Niggli
D2a=[D2a(:,7) (D2a(:,4)+D2a(:,5)) D2a(:,1) D2a(:,21) D2a(:,17) D2a(:,13)];

% D2a now has 6 columns in the following order:
% [Ne Pl Qz Fo Hy Di]

% Need to be reduced to four columns in which the axes are:
% D2=[Ne Qz Fo Di]
% 
D2(:,3)=D2a(:,4)+(D2a(:,5).*0.7);
D2(:,2)=D2a(:,3)+(D2a(:,5).*0.3);
D2(:,1)=D2a(:,1)+(D2a(:,2).*0.5);
D2(:,2)=D2(:,2)+(D2a(:,2).*0.5);
D2(:,4)=D2a(:,6);

%Normalization
suma=sum(D2,2);

for i=1:N(1)
    D2(i,:)=D2(i,:)./suma(i);
end

%  Declare
theta = pi/6;

%  Adjustments
t = 0.5*tan(theta);
S = sqrt(t.^2 + 0.5^2);
for i=1:N(1)
    vS = D2(i,4) .* S;
    vt = vS * sin(theta);
    va = vS * cos(theta);
    IncY = vt;
    IncX = va;
    D(i,3) = D2(i,1) .* sin(2*theta);
    D(i,2) = D2(i,2) + D(i,3) .* cot(2*theta);
    D(i,3) = D(i,3) + IncY;
    D(i,2) = D(i,2) + IncX;
    D(i,4) = D2(i,4) .* (sin(2*theta))^2;
end
D(:,2:4)=10*D(:,2:4);
[tmp,ind]=sort(D(:,1));
ns=1;

for i=1:N
	if i>1 && D(ind(i),1)~=D(ind(i-1),1)
	   fprintf(fid,'\n\n');
           ns=ns+1;
        end
        fprintf(fid,'%f %f %f\n',D(ind(i),2),D(ind(i),3),D(ind(i),4));
end

fclose(fid);
